@@ -14,13 +14,13 @@ case "$1" in
 	;;
 	'-u' | '--uninstall')
 		# remove the replacement icons
-		rm /usr/share/icons/awoken-icon-theme/pixmaps/noor.png /usr/share/pixmaps/noor.png
-		rm /usr/share/icons/awoken-icon-theme/pixmaps/app-search-widget.png /usr/share/pixmaps/app-search-widget.png
-		rm /usr/share/icons/awoken-icon-theme/pixmaps/quicklaunch-search.png /usr/share/pixmaps/quicklaunch-search.png
+		rm /usr/share/pixmaps/noor.png
+		rm /usr/share/pixmaps/app-search-widget.png
+		rm /usr/share/pixmaps/quicklaunch-search.png
 		# restore the original icons
-		mv /usr/share/pixmaps/noor.png /usr/share/pixmaps/noor.png.orig
-		mv /usr/share/pixmaps/app-search-widget.png /usr/share/pixmaps/app-search-widget.png.orig
-		mv /usr/share/pixmaps/quicklaunch-search.png /usr/share/pixmaps/quicklaunch-search.png.orig
+		mv /usr/share/pixmaps/noor.png.orig /usr/share/pixmaps/noor.png
+		mv /usr/share/pixmaps/app-search-widget.png.orig /usr/share/pixmaps/app-search-widget.png
+		mv /usr/share/pixmaps/quicklaunch-search.png.orig /usr/share/pixmaps/quicklaunch-search.png
 		echo "Restoring the original pixmaps icons are done. Restart and the old icons should be shown"
 	;;
 esac
